"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUserInfo = void 0;
const tslib_1 = require("tslib");
const helpers_1 = require("../helpers");
const user_queries_1 = require("../integration-hub-queries/user-queries");
const gql_1 = require("../../codegen/gql");
function getUserInfo(urqlClient) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield gqlGetUserInfo(urqlClient);
            const userInfoFragment = response.data &&
                (0, gql_1.useFragment)(user_queries_1.UserInfoFragment, response.data.authenticatedUser);
            if (userInfoFragment !== null && userInfoFragment !== undefined) {
                return {
                    success: true,
                    data: userInfoFragment,
                };
            }
            return (0, helpers_1.processAsIntegrationHubErrorResponse)(response);
        }
        catch (err) {
            return {
                success: false,
                error: (0, helpers_1.handleCatchError)(err),
            };
        }
    });
}
exports.getUserInfo = getUserInfo;
function gqlGetUserInfo(urqlClient) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return urqlClient.query(user_queries_1.GetUserInfoDocument, {}).toPromise();
    });
}
