"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupEPPaymentsPaymentGateway = void 0;
const tslib_1 = require("tslib");
const integration_hub_1 = require("../../integration-hub");
const update_gateway_1 = require("./update-gateway");
function setupEPPaymentsPaymentGateway(sourceInput, logger) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        try {
            const { epccConfig: { host: epccHost, clientId: epccClientId, clientSecret: epccClientSecret, }, epPaymentsStripeAccountId, } = sourceInput;
            const epccClient = (0, integration_hub_1.createEpccClient)({
                host: epccHost,
                client_id: epccClientId,
                client_secret: epccClientSecret,
            });
            const updateResult = yield (0, update_gateway_1.updateEpPaymentGateway)(epccClient, epPaymentsStripeAccountId);
            if (!updateResult.success) {
                logger.debug(`Failed to update ep payment gateway.`);
                return updateResult;
            }
            return updateResult;
        }
        catch (err) {
            const errorStr = `An unknown error occurred: ${err instanceof Error
                ? `${err.name} = ${err.message}`
                : JSON.stringify(err)}`;
            logger.error(errorStr);
            return {
                success: false,
                error: new Error(errorStr),
            };
        }
    });
}
exports.setupEPPaymentsPaymentGateway = setupEPPaymentsPaymentGateway;
