import { __awaiter } from "tslib";
import { spawn } from "child_process";
import * as path from "path";
import { tags } from "@angular-devkit/core";
export default function (factoryOptions = {}) {
    const rootDirectory = factoryOptions.rootDirectory || process.cwd();
    return (options = {}, context) => __awaiter(this, void 0, void 0, function* () {
        const authorName = options.authorName;
        const authorEmail = options.authorEmail;
        const execute = (args, ignoreErrorStream) => {
            const outputStream = "ignore";
            const errorStream = ignoreErrorStream ? "ignore" : process.stderr;
            const spawnOptions = {
                stdio: [process.stdin, outputStream, errorStream],
                shell: true,
                cwd: path.join(rootDirectory, options.workingDirectory || ""),
                env: Object.assign(Object.assign(Object.assign({}, process.env), (authorName
                    ? { GIT_AUTHOR_NAME: authorName, GIT_COMMITTER_NAME: authorName }
                    : {})), (authorEmail
                    ? {
                        GIT_AUTHOR_EMAIL: authorEmail,
                        GIT_COMMITTER_EMAIL: authorEmail,
                    }
                    : {})),
            };
            return new Promise((resolve, reject) => {
                spawn("git", args, spawnOptions).on("close", (code) => {
                    if (code === 0) {
                        resolve();
                    }
                    else {
                        reject(code);
                    }
                });
            });
        };
        const hasCommand = yield execute(["--version"]).then(() => true, () => false);
        if (!hasCommand) {
            return;
        }
        const insideRepo = yield execute(["rev-parse", "--is-inside-work-tree"], true).then(() => true, () => false);
        if (insideRepo) {
            context.logger.info(tags.oneLine `
        Directory is already under version control.
        Skipping initialization of git.
      `);
            return;
        }
        try {
            yield execute(["init"]);
            yield execute(["add", "."]);
            if (options.commit) {
                const message = options.message || "initial commit";
                yield execute(["commit", `-m "${message}"`]);
            }
            context.logger.info("Successfully initialized git.");
        }
        catch (_a) { }
    });
}
